import React, { PureComponent } from 'react';
import PropTypes from 'prop-types';

function styleInject(css, ref) {
  if ( ref === void 0 ) ref = {};
  var insertAt = ref.insertAt;

  if (!css || typeof document === 'undefined') { return; }

  var head = document.head || document.getElementsByTagName('head')[0];
  var style = document.createElement('style');
  style.type = 'text/css';

  if (insertAt === 'top') {
    if (head.firstChild) {
      head.insertBefore(style, head.firstChild);
    } else {
      head.appendChild(style);
    }
  } else {
    head.appendChild(style);
  }

  if (style.styleSheet) {
    style.styleSheet.cssText = css;
  } else {
    style.appendChild(document.createTextNode(css));
  }
}

var css = "/* add css styles here (optional) */\n\n.styles_test__32Qsm {\n  display: inline-block;\n  margin: 2em auto;\n  border: 2px solid #000;\n  font-size: 2em;\n}\n\n.styles_popupContainer__217in {\n  position: fixed;\n  top: 0;\n  left: 0;\n  right: 0;\n  bottom: 0;\n  display: flex;\n  background-color: #222222B3;\n}\n\n.styles_popupContent__13KCO {\n  display: flex;\n  flex: 1;\n  margin-left: 50px;\n  margin-right: 50px;\n  margin-top: 50px;\n  margin-bottom: 50px;\n}\n\n.styles_popupiframe__3TMhb {\n  background-color: #22222280;\n  background-image: url(https://raw.githubusercontent.com/nclong87/nclong87.github.io/master/spinner3.gif);\n  background-repeat: no-repeat;\n  background-position: 50% 50%;\n}\n";
var styles = { "test": "styles_test__32Qsm", "popupContainer": "styles_popupContainer__217in", "popupContent": "styles_popupContent__13KCO", "popupiframe": "styles_popupiframe__3TMhb" };
styleInject(css);

var classCallCheck = function (instance, Constructor) {
  if (!(instance instanceof Constructor)) {
    throw new TypeError("Cannot call a class as a function");
  }
};

var createClass = function () {
  function defineProperties(target, props) {
    for (var i = 0; i < props.length; i++) {
      var descriptor = props[i];
      descriptor.enumerable = descriptor.enumerable || false;
      descriptor.configurable = true;
      if ("value" in descriptor) descriptor.writable = true;
      Object.defineProperty(target, descriptor.key, descriptor);
    }
  }

  return function (Constructor, protoProps, staticProps) {
    if (protoProps) defineProperties(Constructor.prototype, protoProps);
    if (staticProps) defineProperties(Constructor, staticProps);
    return Constructor;
  };
}();

var inherits = function (subClass, superClass) {
  if (typeof superClass !== "function" && superClass !== null) {
    throw new TypeError("Super expression must either be null or a function, not " + typeof superClass);
  }

  subClass.prototype = Object.create(superClass && superClass.prototype, {
    constructor: {
      value: subClass,
      enumerable: false,
      writable: true,
      configurable: true
    }
  });
  if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass;
};

var possibleConstructorReturn = function (self, call) {
  if (!self) {
    throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
  }

  return call && (typeof call === "object" || typeof call === "function") ? call : self;
};

var PDF = function (_PureComponent) {
  inherits(PDF, _PureComponent);

  function PDF(props) {
    classCallCheck(this, PDF);

    var _this = possibleConstructorReturn(this, (PDF.__proto__ || Object.getPrototypeOf(PDF)).call(this, props));

    _this.state = {
      currentPage: 1
    };
    _this.totalPages = 0;
    _this.handleOnReceived = _this.handleOnReceived.bind(_this);
    _this.handleDispatchKeydownToIframe = _this.handleDispatchKeydownToIframe.bind(_this);
    _this.handlePressEscape = _this.handlePressEscape.bind(_this);
    _this.handleClickOnPopupContainer = _this.handleClickOnPopupContainer.bind(_this);
    _this.goToPage = _this.goToPage.bind(_this);
    _this.startPresentation = _this.startPresentation.bind(_this);
    _this.sendDocumentState = _this.sendDocumentState.bind(_this);
    return _this;
  }

  createClass(PDF, [{
    key: 'componentDidMount',
    value: function componentDidMount() {
      window.addEventListener('message', this.handleOnReceived);
      document.addEventListener('keydown', this.handleDispatchKeydownToIframe, false);
    }
  }, {
    key: 'componentDidUpdate',
    value: function componentDidUpdate(prevProps, prevState) {
      var currentPage = this.state.currentPage;

      if (prevState.currentPage !== currentPage) {
        this.props.onPageChanged(currentPage);
      }
      if (prevProps.downloadable !== this.props.downloadable || prevProps.preview !== this.props.preview) {
        var resource = {
          downloadable: this.props.downloadable,
          preview: this.props.preview
        };
        var host = this.props.viewer.host;
        this.iframe.contentWindow.postMessage({ message: 'onResourceChanged', data: resource }, host);
      }
    }
  }, {
    key: 'componentWillUnmount',
    value: function componentWillUnmount() {
      window.removeEventListener('message', this.handleOnReceived, false);
      document.removeEventListener('keydown', this.handleDispatchKeydownToIframe, false);
    }
  }, {
    key: 'goToPage',
    value: function goToPage(page) {
      // console.log('goToPage1', page)
      var host = this.props.viewer.host;
      this.iframe.contentWindow.postMessage({ message: 'onPageChanged', data: page }, host);
    }
  }, {
    key: 'startPresentation',
    value: function startPresentation(data) {
      var host = this.props.viewer.host;
      this.iframe.contentWindow.postMessage({ message: 'onPresentationStarted', data: data }, host);
    }
  }, {
    key: 'sendDocumentState',
    value: function sendDocumentState(data) {
      var host = this.props.viewer.host;
      this.iframe.contentWindow.postMessage({ message: 'onStateChanged', data: data }, host);
    }
  }, {
    key: 'handleDispatchKeydownToIframe',
    value: function handleDispatchKeydownToIframe(event) {
      var host = this.props.viewer.host;
      var key = event.key,
          keyCode = event.keyCode;

      this.iframe.contentWindow.postMessage({ message: 'onKeydown', data: { key: key, keyCode: keyCode } }, host);
      // this.iframe.contentWindow.dispatchEvent(
      //   new KeyboardEvent('keydown', { key: event.key }), host
      // )
    }
  }, {
    key: 'handlePressEscape',
    value: function handlePressEscape(e) {
      if (e.keyCode === 27) {
        if (typeof e.preventDefault === 'function') {
          e.preventDefault();
        }
        if (typeof e.stopPropagation === 'function') {
          e.stopPropagation();
        }
        this.props.onRequestClose();
      }
    }
  }, {
    key: 'handleClickOnPopupContainer',
    value: function handleClickOnPopupContainer(e) {
      // console.log('handleClickOnPopupContainer', e.target)
      if (e.target.className.indexOf('popupContainer') >= 0) {
        this.props.onRequestClose();
      }
    }
  }, {
    key: 'handleOnReceived',
    value: function handleOnReceived(event) {
      var host = this.props.viewer.host;
      if (event.origin !== host) {
        return;
      }
      if (event.data && event.data.type) {
        // console.log('Received Message : ', event)
        if (!this.iframe) {
          return;
        }
        switch (event.data.type) {
          case 'ready':
            {
              var resource = {
                src: this.props.src,
                popup: this.props.popup,
                downloadable: this.props.downloadable,
                preview: this.props.preview
              };
              this.iframe.contentWindow.postMessage({ message: 'onResourceChanged', data: resource }, host);
              break;
            }
          case 'close':
            this.props.onRequestClose();
            break;
          case 'documentloaded':
            {
              var pagesCount = event.data.data.pagesCount;

              this.totalPages = pagesCount;
              this.props.onLoaded();
              break;
            }
          case 'pagechanging':
            {
              var pageNumber = event.data.data.pageNumber;

              this.setState({ currentPage: pageNumber });
              break;
            }
          case 'pagerendered':
            {
              var _pageNumber = event.data.data.pageNumber;

              if (this.totalPages > 0 && _pageNumber === this.totalPages) {
                this.props.onLastPage();
              }
              break;
            }
          default:
            break;
        }
      }
    }
  }, {
    key: 'renderIframe',
    value: function renderIframe() {
      var _this2 = this;

      var _props$viewer = this.props.viewer,
          host = _props$viewer.host,
          path = _props$viewer.path;

      var style = { width: '100%', height: '100%' };
      return React.createElement('iframe', {
        ref: function ref(el) {
          _this2.iframe = el;
        },
        className: this.props.popup ? styles.popupiframe : '',
        frameBorder: '0',
        allowFullScreen: true,
        style: style,
        title: 'PDF Reader',
        src: '' + host + path
      });
    }
  }, {
    key: 'render',
    value: function render() {
      if (this.props.popup) {
        return React.createElement(
          'div',
          {
            role: 'button',
            tabIndex: 0,
            className: styles.popupContainer,
            onClick: this.handleClickOnPopupContainer
          },
          React.createElement(
            'div',
            { className: styles.popupContent },
            this.renderIframe()
          )
        );
      }
      return this.renderIframe();
    }
  }]);
  return PDF;
}(PureComponent);

PDF.propTypes = {
  viewer: PropTypes.instanceOf(Object),
  popup: PropTypes.bool,
  downloadable: PropTypes.bool,
  preview: PropTypes.bool,
  src: PropTypes.oneOfType([PropTypes.string, PropTypes.instanceOf(Object)]).isRequired,
  onLoaded: PropTypes.func,
  onPageChanged: PropTypes.func,
  onLastPage: PropTypes.func,
  onRequestClose: PropTypes.func
};

PDF.defaultProps = {
  viewer: {
    host: 'https://nclong87.github.io',
    path: '/web/viewer.html'
  },
  popup: false,
  downloadable: false,
  preview: false,
  onLoaded: function onLoaded() {
    return null;
  },
  onPageChanged: function onPageChanged() {
    return null;
  },
  onRequestClose: function onRequestClose() {
    return null;
  },
  onLastPage: function onLastPage() {
    return null;
  }
};

export default PDF;
//# sourceMappingURL=index.es.js.map
